@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Hayo Baan's Dist::Zilla configuration
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -117,6 +117,8 @@ our $VERSION = '0.007'; # VERSION
 #pod
 #pod Adding this option will force keep the version number the same (regardless of the other settings above!).
 #pod
+#pod C<--keep> is a synonym for this option.
+#pod
 #pod =head1 CREDITS
 #pod
 #pod I took inspiration from many people's L<Dist::Zilla> and L<Pod::Weaver> PluginBundles. Most notably from:
@@ -626,6 +628,11 @@ sub configure {
         my $major;
         GetOptions('major|major-relase|make-major|make-major-release!' => \$major);
         $self->make_major_release($major) if defined $major;
+
+        # Keep-version
+        my $keep;
+        GetOptions('keep|keep-version!' => \$keep);
+        $self->keep_version($keep) if defined $keep;
     }
 
     return $self->add_plugins(
@@ -642,7 +649,7 @@ sub configure {
                     version_regexp        => $self->version_regexp,      # Regexp for version format
                     include_minor_version => $self->make_minor_release,  # Minor release?
                     remove_minor_version  => $self->make_major_release,  # Force major release?
-                    inhibit_version_bump  => $self->keep_version,        # Keep release?
+                    keep_version          => $self->keep_version,        # Keep release number?
                 },
             ],
         ),
@@ -867,7 +874,7 @@ Dist::Zilla::PluginBundle::Author::HAYOBAAN - Hayo Baan's Dist::Zilla configurat
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
@@ -1168,6 +1175,8 @@ Note: Overrides L<--make-minor-release>.
 
 Adding this option will force keep the version number the same (regardless of the other settings above!).
 
+C<--keep> is a synonym for this option.
+
 =head1 ATTRIBUTES
 
 =head2 is_cpan
